@@ -1,4 +1,4 @@
-from django.conf.urls.defaults import *
+from django.conf.urls import *
 
 urlpatterns = patterns('',
     url(r'^(?P<app_name>[\w-]+)/(?P<model_name>[\w-]+)/multiple/$',
